import Config

config :release_test, :static, :was_set
config :release_test, :encoding, {:"£", "£", '£'}
